timeintervaltools.group_overlapping_intervals_and_yield_groups
==============================================================

.. autofunction:: abjad.tools.timeintervaltools.group_overlapping_intervals_and_yield_groups.group_overlapping_intervals_and_yield_groups
